// MSP430F5529
//                 -----------------
//                |             P4.1|-> SEN
//                |                 |
//                |             P1.0|-> LED
//                |                 |
//                |             P3.3|-> Data Out (UCA0SIMO)
//                | USCA1           |
//      TXD <---- | P4.4        P3.4|<- Data In (UCA0SOMI)
//      RXD  ---->| P4.5            |
//                |             P2.7|-> Serial Clock Out (UCA0CLK)







#include <msp430.h>

const unsigned char READ1=0x40;


unsigned char DATO;


int main(void)
{
  volatile unsigned int i;

  WDTCTL = WDTPW+WDTHOLD;                                       // Stop watchdog timer

  P1DIR |= 0xFF;                                                // Set P1.0 for LED
  P1SEL |=0x00;                                          	    // Set P1.1 for slave reset
  P2DIR |=0xFF;
  P2SEL |=0x00;
  P2SEL |= BIT7;                            			        // P2.7 option select
  P3DIR |=0xFF;
  P3SEL |=0X00;
  P3SEL |= BIT3+BIT4;                                           // P3.3,4 option select
  P4DIR |= 0xFF;
  P4SEL |=0x10;
  P6DIR |= 0xFF;
  P6SEL |=0x00;                                                 //set all pin

  //SET SPI (USCIA0)
  UCA0CTL1 |= UCSWRST;                               			// **Put state machine in reset**
  P4OUT|=BIT1;                                                  //sen=1
  UCA0CTL1 |= UCSSEL_1;                              			// ACLK (32KHz)
  UCA0BR0 = 0x00;                                   			// no clock scale factor
  UCA0BR1 = 0x00;
  UCA0MCTL = 0x00;                                  			// No modulation

  UCA0CTL0 |=UCMSB+UCMST+UCSYNC;           			            // 8-bit,sync mode, SPI master mode, MSB first

  UCA0CTL1 &= ~UCSWRST;                    			            // **Initialize USCI state machine**
  UCA0IE |= UCTXIE;                         			        // Enable USCI_A0 TX, RX interrupt

  //SET UART1(USCIA1)

  UCA1CTL1 |= UCSWRST;                      			         // **Put state machine in reset**

  UCA1CTL1 |= UCSSEL_1;                    			             // ACLK (32KHz)
  UCA1BR0   = 0x03;                              	             // BAUD RATE 9600
  UCA1BR1   = 0x00;
  UCA1MCTL  = 0x06;
  UCA1CTL0  = 0x00;                                              //PARITY, STOP, 8BIT.

  UCA1CTL1 &= ~UCSWRST;                                          // **Initialize USCIA1 state machine**

  for(i=50;i>0;i--);


  __bis_SR_register(LPM0_bits + GIE);       			         // CPU off, enable interrupts
  __no_operation();                                              // For debugger
}

#pragma vector=USCI_A0_VECTOR               			         //dichiarare una funzione come Interrupt Service Routine
__interrupt void USCI_A0_ISR(void)

{
  int j;
  volatile unsigned int i;


  P1OUT  |= BIT0;
  switch(__even_in_range(UCA0IV,4))
  {
    case 0: break;                          			         // Vector 0 - no interrupt
    case 2:                                                      // Vector 2 - RXIFG


          break;
    case 4:                                 			         // Vector 4 - TXIFG
    	for(j=0x64; j<=0x67; j++)
    	 {
    		for(i=50;i>0;i--);
    	    UCA0TXBUF = READ1;                                   // Transmit first command
    	    while (!(UCA0IFG&UCTXIFG));               			 // USCI_A0 TX buffer ready?
    	    UCA0TXBUF =j;                                        // Transmit second command
    	    for(i=50;i>0;i--);
            while (!(UCA0IFG&UCTXIFG));
    	    UCA0TXBUF = 0x00;
    	    while (!(UCA0IFG&UCRXIFG));
    	    for(i=50;i>0;i--);
    	    DATO = UCA0RXBUF;
    	    P4OUT&=~BIT1;                                         //sen=0
    	    while (!(UCA1IFG&UCTXIFG));

    	    UCA1TXBUF=DATO;

    	    for(i=50 ;i>0 ; i--);
    	    P4OUT|=BIT1;
    	    for(i=50;i>0;i--);

    	  }
    	  break;
    default: break;

  }
  P1OUT  &= 0X00;

  while(1);
}



